summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
Diffstat (limited to 'png.h')
-rw-r--r--png.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/png.h b/png.h
index 58728a655..89ec7862a 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.0.52rc01 - December 23, 2009
- * Copyright (c) 1998-2009 Glenn Randers-Pehrson
+ * libpng version 1.0.52rc02 - January 1, 2010
+ * Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
*
@@ -10,7 +10,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.0.52rc01 - December 23, 2009: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -251,7 +251,7 @@
* 1.0.51 10 10051 10.so.0.51[.0]
* 1.2.41 13 10241 12.so.0.41[.0]
* 1.2.42beta01-02 13 10242 12.so.0.42[.0]
- * 1.2.42rc01-02 13 10242 12.so.0.42[.0]
+ * 1.2.42rc01-04 13 10242 12.so.0.42[.0]
* 1.0.52 10 10052 10.so.0.52[.0]
* 1.2.42 13 10242 12.so.0.42[.0]
*
@@ -285,8 +285,8 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.0.52rc01, December 23, 2009, are
* Copyright (c) 2004, 2006-2009 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
*
@@ -397,13 +397,13 @@
* Y2K compliance in libpng:
* =========================
*
- * December 23, 2009
+ * January 1, 2010
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.0.52rc01 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -459,9 +459,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.0.52rc01"
+#define PNG_LIBPNG_VER_STRING "1.0.52rc02"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.0.52rc01 - December 23, 2009\n"
+ " libpng version 1.0.52rc02 - January 1, 2010\n"
#define PNG_LIBPNG_VER_SONUM 0
#define PNG_LIBPNG_VER_DLLNUM 10
@@ -474,7 +474,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 01
+#define PNG_LIBPNG_VER_BUILD 02
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -1530,7 +1530,7 @@ struct png_struct_def
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef png_structp version_1_0_52rc01;
+typedef png_structp version_1_0_52rc02;
typedef png_struct FAR * FAR * png_structpp;
@@ -2173,10 +2173,10 @@ extern PNG_EXPORT(void,png_free_default) PNGARG((png_structp png_ptr,
#endif
extern PNG_EXPORT(png_voidp,png_memcpy_check) PNGARG((png_structp png_ptr,
- png_voidp s1, png_voidp s2, png_uint_32 size));
+ png_voidp s1, png_voidp s2, png_uint_32 size)) PNG_DEPRECATED;
extern PNG_EXPORT(png_voidp,png_memset_check) PNGARG((png_structp png_ptr,
- png_voidp s1, int value, png_uint_32 size));
+ png_voidp s1, int value, png_uint_32 size)) PNG_DEPRECATED;
#if defined(USE_FAR_KEYWORD) /* memory model conversion function */
extern void *png_far_to_near PNGARG((png_structp png_ptr,png_voidp ptr,
@@ -10,7 +10,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.0.52rc01 - December 23, 2009: Glenn
+ * libpng versions 0.97, January 1998, through 1.0.52rc02 - January 1, 2010: Glenn
* See also "Contributing Authors", below.
*
@@ -285,8 +285,8 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.0.52rc01, December 23, 2009, are
- * Copyright (c) 2004, 2006-2009 Glenn Randers-Pehrson, and are
+ * libpng versions 1.2.6, August 15, 2004, through 1.0.52rc02, January 1, 2010, are
+ * Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -397,13 +397,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.0.52rc01 are Y2K compliant. It is my belief that earlier
+ * upward through 1.0.52rc02 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*